"""pytest_sigil - Proper fixture resource cleanup by handling signals."""

__version__ = "1.0.0"

import pathlib

_PACKAGE_ROOT_DIRECTORY = pathlib.Path(__file__).resolve().parent
"""The root directory of the installed package."""

_DISTRIBUTION_PACKAGE_NAME = "PYTEST_SIGIL"
"""Distribution name of this package, upper case & underscore separators.

.. note:: Use this as prefix when defining environment variables for this package.
"""

_PYTEST_PLUGIN_NAME = "sigil"
"""Name of the pytest plugin provided by this package."""



import signal

import pytest

_SIGTERM_SIGNAL_HANDLER = pytest.StashKey[signal.Handlers]()


@pytest.hookimpl(tryfirst=True)
def pytest_sessionstart(session: pytest.Session) -> None:
    """Reroute SIGTERM → SIGINT early in the pytest lifecycle."""
    session.stash[_SIGTERM_SIGNAL_HANDLER] = signal.signal(  # type: ignore[misc]  # signal type hints (typeshed) are lacking
        signal.SIGTERM, signal.getsignal(signal.SIGINT)
    )


@pytest.hookimpl(trylast=True)
def pytest_sessionfinish(session: pytest.Session) -> None:
    """Restore SIGTERM handler after pytest completes."""
    original = session.stash[_SIGTERM_SIGNAL_HANDLER]
    signal.signal(signal.SIGTERM, original)
